<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class CardsFactory{
    
    use TQuery;
    
    protected $connection;
    protected $entityManager;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function buscaTipoLocal() {
        $sql = "SELECT NMTIPOLOCALCLI, NRTIPOLOCALCLI
                  FROM FCM_TIPOLOCALCLI";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaLocal() {
        $sql = "SELECT NRLOCALCLIENTE,NMLOCALCLIENTE
                  FROM FCM_LOCALCLI
                  WHERE NRLOCALCLIENTEPAI IS NOT NULL";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaChecklist() {
        $sql = "SELECT NRCHECKLIST, NMCHECKLIST
                  FROM FCM_CHECKLIST";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function getItensChecklist() {
        $sql = "SELECT FCM_ATIVIDADECHK.NRATIVIDADECHK, FCM_ATIVIDADE.NMATIVIDADE, FCM_ATIVIDADECHK.NRCHECKLIST
                  FROM FCM_ATIVIDADE
                  JOIN FCM_ATIVIDADECHK
                    ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE";
                
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaItensChecklist($param) {
        $sql = "SELECT FCM_ATIVIDADECHK.NRATIVIDADECHK, FCM_ATIVIDADE.NMATIVIDADE 
                  FROM FCM_ATIVIDADE
                  JOIN FCM_ATIVIDADECHK
                    ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE
                  JOIN FCM_CHECKLIST
                    ON FCM_ATIVIDADECHK.NRCHECKLIST = FCM_CHECKLIST.NRCHECKLIST
                 WHERE FCM_CHECKLIST.NRCHECKLIST = ".$param['NRCHECKLIST'];
                
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }

    public function buscaFuncionario() {
        $sql = "SELECT FUNC.NRFUNCIONARIO, FUNC.NMFUNCIONARIO
                FROM FCM_FUNCIONARIO FUNC
                LEFT JOIN FCM_FUNCIONARIOSHIERARQ FHIER
                  ON FHIER.NRFUNCIONARIO = FUNC.NRFUNCIONARIO                    
                WHERE FHIER.NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S')
                  AND FUNC.NRFUNCIONARIO NOT IN (SELECT DISTINCT NVL(NRFUNCIONARIOPAI,0) AS NRFUNCIONARIO
                            FROM FCM_FUNCIONARIOSHIERARQ 
                           WHERE  NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S'))";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscandoSupervisor() {
        $sql = "SELECT FUNC.NRFUNCIONARIO, FUNC.NMFUNCIONARIO
                FROM FCM_FUNCIONARIO FUNC
                LEFT JOIN FCM_FUNCIONARIOSHIERARQ FHIER
                  ON FHIER.NRFUNCIONARIO = FUNC.NRFUNCIONARIO                    
                WHERE FHIER.NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S')
                  AND FUNC.NRFUNCIONARIO IN (SELECT DISTINCT NVL(NRFUNCIONARIOPAI,0) AS NRFUNCIONARIO
                            FROM FCM_FUNCIONARIOSHIERARQ 
                           WHERE  NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S'))";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    public function buscaFuncionarioDataSource() {
        $sql = "SELECT FUNC.NRFUNCIONARIO, FUNC.NMFUNCIONARIO
                FROM FCM_FUNCIONARIO FUNC
                LEFT JOIN FCM_FUNCIONARIOSHIERARQ FHIER
                  ON FHIER.NRFUNCIONARIO = FUNC.NRFUNCIONARIO                    
                WHERE FHIER.NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S')
                  AND FUNC.NRFUNCIONARIO NOT IN (SELECT DISTINCT NVL(NRFUNCIONARIOPAI,0) AS NRFUNCIONARIO
                            FROM FCM_FUNCIONARIOSHIERARQ 
                           WHERE  NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S'))";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }
    
    public function buscandoSupervisorDataSource() {
        $sql = "SELECT FUNC.NRFUNCIONARIO AS NRENCARREGADO, FUNC.NMFUNCIONARIO AS NMENCARREGADO
                FROM FCM_FUNCIONARIO FUNC
                LEFT JOIN FCM_FUNCIONARIOSHIERARQ FHIER
                  ON FHIER.NRFUNCIONARIO = FUNC.NRFUNCIONARIO                    
                WHERE FHIER.NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S')
                  AND FUNC.NRFUNCIONARIO IN (SELECT DISTINCT NVL(NRFUNCIONARIOPAI,0) AS NRFUNCIONARIO
                            FROM FCM_FUNCIONARIOSHIERARQ 
                           WHERE  NRHIERARQUIAFUNC IN (SELECT NRHIERARQUIAFUNC 
                                                   FROM FCM_HIERARQUIAFUNC 
                                                  WHERE IDATIVO = 'S'))";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function buscaCriterioTarefa($params) {
        $sql = "SELECT NRTAREFACHK, NMTAREFACHK
                  FROM FCM_TAREFACHK
                  WHERE NRCHECKLIST IN (".$params['NRCHECKLIST'].")";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscaTarefa($params) {
        $sql = "SELECT A.NRTAREFACHK, C.NMTAREFA
                FROM FCM_TAREFACHK A
                JOIN FCM_ATIVIDADECHK B
                ON A.NRATIVIDADECHK = B.NRATIVIDADECHK
                JOIN FCM_TAREFA C
                ON A.NRTAREFA = C.NRTAREFA
                WHERE B.NRATIVIDADECHK IN (".$params['NRATIVIDADE'].")";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscaCriterioAtividade($params){
        $sql = "SELECT A.NRCRITERIOTAREFACHK, A.NRCRITERIOTAREFA,B.DSCRITERIOTAREFA, A.NRTAREFACHK, E.NRCHECKLIST, D.NRATIVIDADECHK
                  FROM FCM_CRITERIOTAREFACHK A
                  JOIN FCM_CRITERIOTAREFA B
                ON A.NRCRITERIOTAREFA = B.NRCRITERIOTAREFA
                JOIN FCM_TAREFACHK C
                ON A.NRTAREFACHK = C.NRTAREFACHK
                JOIN FCM_ATIVIDADECHK D
                ON C.NRATIVIDADECHK = D.NRATIVIDADECHK
                JOIN FCM_CHECKLIST E
                ON E.NRCHECKLIST = D.NRCHECKLIST
                WHERE E.NRCHECKLIST = ".$params['NRCHECKLIST']."
                AND D.NRATIVIDADECHK IN (".$params['NRATIVIDADECHK'].")
                AND C.NRTAREFACHK IN (".$params['NRTAREFACHK'].")";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function getCriterios(){
        $sql = "SELECT A.NRCRITERIOTAREFACHK, A.NRCRITERIOTAREFA,B.DSCRITERIOTAREFA, A.NRTAREFACHK, E.NRCHECKLIST, D.NRATIVIDADECHK
                  FROM FCM_CRITERIOTAREFACHK A
                  JOIN FCM_CRITERIOTAREFA B
                ON A.NRCRITERIOTAREFA = B.NRCRITERIOTAREFA
                JOIN FCM_TAREFACHK C
                ON A.NRTAREFACHK = C.NRTAREFACHK
                JOIN FCM_ATIVIDADECHK D
                ON C.NRATIVIDADECHK = D.NRATIVIDADECHK
                JOIN FCM_CHECKLIST E
                ON E.NRCHECKLIST = D.NRCHECKLIST";
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function buscaCard($hierarchyParam, $filtrar){
       $sql = "SELECT DISTINCT FCM_CHECKLISTAGEND.NRCHECKLISTAGEND, FCM_CHECKLISTAGEND.NMCHECKLISTAGEND, TO_CHAR(FCM_CHECKLISTAGEND.DTHORAAGEND, 'DD/MM/YYYY HH24:MI') AS DTHORAAGEND,
                TO_CHAR(FCM_CHECKLISTAGEND.DTHRFINALAGEND, 'DD/MM/YYYY HH24:MI') AS DTHRFINALAGEND,
                FCM_LOCALCLI.NRLOCALCLIENTE, FCM_LOCALCLI.NMLOCALCLIENTE,
                FCM_TIPOLOCALCLI.NRTIPOLOCALCLI, FCM_TIPOLOCALCLI.NMTIPOLOCALCLI,
                FCM_LOCALCLIPAI.NRLOCALCLIENTE AS NRLOCALCLIENTEPAI, FCM_LOCALCLIPAI.NMLOCALCLIENTE AS NMLOCALCLIENTEPAI,
                FCM_CHECKLIST.NRCHECKLIST, FCM_CHECKLIST.NMCHECKLIST,
                FCM_TAREFA.NRTAREFA, FCM_TAREFA.NMTAREFA,
                FCM_TAREFAAGEND.NRTAREFACHK,
                FCM_ATIVIDADE.NRATIVIDADE, FCM_ATIVIDADE.NMATIVIDADE,
                FCM_ESCOPOSTAREFA.NRESCOPOSTAREFA, FCM_ESCOPOSTAREFA.NMESCOPOSTAREFA, FCM_ATIVIDADECHK.NRATIVIDADECHK,
                FCM_CRITERIOTAREFA.NRCRITERIOTAREFA, FCM_CRITERIOTAREFA.DSCRITERIOTAREFA,
                FCM_FUNCIONARIO.NRFUNCIONARIO, FCM_FUNCIONARIO.NMFUNCIONARIO,
                FCM_FUNCIONARIOVISTORIA.NRFUNCIONARIO AS NRENCARREGADO, FCM_FUNCIONARIOVISTORIA.NMFUNCIONARIO AS NMENCARREGADO,
                FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK,
                FCM_CHECKLISTAGEND.IDSITUACAOAGEND ,CASE FCM_CHECKLISTAGEND.IDSITUACAOAGEND 
                WHEN '1' THEN 'Pendente'
                WHEN '2' THEN 'Em Andamento'
                WHEN '3' THEN 'Concluido'
                WHEN '4' THEN 'Cancelado'
                ELSE NULL END AS NMIDSITUACAOAGEND
          FROM FCM_CHECKLISTAGEND
          JOIN FCM_LOCALCLI
            ON FCM_CHECKLISTAGEND.NRLOCALCLIENTE = FCM_LOCALCLI.NRLOCALCLIENTE
          JOIN FCM_TIPOLOCALCLI
            ON FCM_LOCALCLI.NRTIPOLOCALCLI = FCM_TIPOLOCALCLI.NRTIPOLOCALCLI
          JOIN FCM_LOCALCLI FCM_LOCALCLIPAI
            ON FCM_LOCALCLI.NRLOCALCLIENTEPAI = FCM_LOCALCLIPAI.NRLOCALCLIENTE
          JOIN FCM_CHECKLIST
            ON FCM_TIPOLOCALCLI.NRTIPOLOCALCLI = FCM_CHECKLIST.NRTIPOLOCALCLI
          JOIN FCM_TAREFAAGEND
            ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_TAREFAAGEND.NRCHECKLISTAGEND
          JOIN FCM_TAREFACHK
            ON FCM_TAREFAAGEND.NRTAREFACHK = FCM_TAREFACHK.NRTAREFACHK
          JOIN FCM_TAREFA
            ON FCM_TAREFACHK.NRTAREFA = FCM_TAREFA.NRTAREFA
          JOIN FCM_ATIVIDADE
            ON FCM_TAREFA.NRATIVIDADE = FCM_ATIVIDADE.NRATIVIDADE
     LEFT JOIN FCM_ATIVIDADECHK
            ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE
     LEFT JOIN FCM_TAGSCHKTAREFA
            ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAGSCHKTAREFA.NRTAREFACHK
     LEFT JOIN FCM_TAGSTAREFA
            ON FCM_TAGSCHKTAREFA.NRTAGSTAREFA = FCM_TAGSTAREFA.NRTAGSTAREFA
     LEFT JOIN FCM_ESCOPOSTAREFA
            ON FCM_TAGSTAREFA.NRESCOPOSTAREFA = FCM_ESCOPOSTAREFA.NRESCOPOSTAREFA
     LEFT JOIN FCM_CRITERIOTARAGEND
            ON FCM_TAREFAAGEND.NRTAREFAAGEND = FCM_CRITERIOTARAGEND.NRTAREFAAGEND
          JOIN FCM_CRITERIOTAREFACHK
            ON FCM_CRITERIOTARAGEND.NRCRITERIOTAREFACHK = FCM_CRITERIOTAREFACHK.NRCRITERIOTAREFACHK
          JOIN FCM_CRITERIOTAREFA
            ON FCM_CRITERIOTAREFACHK.NRCRITERIOTAREFA = FCM_CRITERIOTAREFA.NRCRITERIOTAREFA
          JOIN FCM_FUNCIONARIO
            ON FCM_CHECKLISTAGEND.NRFUNCIONARIO = FCM_FUNCIONARIO.NRFUNCIONARIO
          JOIN FCM_GERENCIAMENTOCHK
            ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_GERENCIAMENTOCHK.NRCHECKLISTAGEND
          JOIN FCM_FUNCIONARIO FCM_FUNCIONARIOVISTORIA
            ON FCM_GERENCIAMENTOCHK.NRFUNCIONARIO = FCM_FUNCIONARIOVISTORIA.NRFUNCIONARIO
         WHERE FCM_CHECKLISTAGEND.NRFUNCIONARIO IN ({$hierarchyParam['NRFUNCIONARIO']})".$filtrar."
      ORDER BY FCM_CHECKLISTAGEND.NRCHECKLISTAGEND ASC";
        
        $std = $this->connection->prepare($sql);
        $std->execute();
        return $std->fetchAll();
    }
    
    public function insertNovaTarefa($param){
        $sql="INSERT INTO FCM_CHECKLISTAGEND (NRCHECKLISTAGEND, NMCHECKLISTAGEND, NRLOCALCLIENTE, NRCHECKLIST, NRFUNCIONARIO, 
                                              IDSITUACAOAGEND, DTHORAAGEND,  IDATIVO, DTINCLUSAO, DTHRFINALAGEND,
                                              CDOPERINCLUSAO)
              VALUES (:NRCHECKLISTAGEND, :NMCHECKLISTAGEND, :NRLOCALCLIENTE, :NRCHECKLIST, :NRFUNCIONARIO, 
                      :IDSITUACAOAGEND,TO_DATE(:DTHORAAGEND,'YYYY/MM/DD HH24:MI'),  'S', SYSDATE, TO_DATE(:DTHRFINALAGEND,'YYYY/MM/DD HH24:MI'),
                      :OPERADOR)";
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function insertNovaTarefa2($param){
        $sql="INSERT INTO FCM_TAREFAAGEND (NRTAREFAAGEND, NRCHECKLISTAGEND, NRTAREFACHK, NRFUNCIONARIO, DTHORATAREFAAGEND, 
                                           DSOBSTAREFAAGEND, IDREALIZADO,  IDATIVO, DTINCLUSAO, 
                                           CDOPERINCLUSAO, NRTAREFARECORRENTE)
              VALUES (:NRTAREFAAGEND, :NRCHECKLISTAGEND, :NRTAREFACHK, :NRFUNCIONARIO, TO_DATE(:DTHORAAGEND,'YYYY/MM/DD HH24:MI'), 
                      :DSOBSTAREFAAGEND, 'N',  'S', SYSDATE, 
                      :OPERADOR, :NRTAREFARECORRENTE)";
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function insertNovaTarefa3($param){
        $sql="INSERT INTO FCM_CRITERIOTARAGEND (NRCRITERIOTARAGEND, NMCRITERIOTARAGEND, NRTAREFAAGEND, NRCRITERIOTAREFACHK, IDATIVO,
                                                DTINCLUSAO, CDOPERINCLUSAO)
                                        VALUES (:NRCRITERIOTARAGEND,:NMCRITERIOTARAGEND, :NRTAREFAAGEND, :NRCRITERIOTAREFACHK, 'S',
                                                SYSDATE, :OPERADOR)";
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
        
    public function insertNovaTarefa4($param){
        $sql="INSERT INTO FCM_GERENCIAMENTOCHK (NRGERENCIAMENTOCHK, NMGERENCIAMENTOCHK, NRLOCALCLIENTE, NRCHECKLIST, NRFUNCIONARIO, 
                             IDSITUACAOGERCHK, DTHORAAGEND, IDATIVO, DTINCLUSAO, 
                             CDOPERINCLUSAO, NRCHECKLISTAGEND,DTHRFINALAGEND)
       VALUES (:NRGERENCIAMENTOCHK, :NMGERENCIAMENTOCHK, :NRLOCALCLIENTE, :NRCHECKLIST, :NRFUNCIONARIO, 
                             '1',  :DTHORAAGEND, 'S', SYSDATE, 
                             :OPERADOR, :NRCHECKLISTAGEND,TO_DATE(:DTHRFINALAGEND,'YYYY/MM/DD HH24:MI'))";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function insertNovaTarefa5($param){
        $sql="INSERT INTO FCM_TAREFAGERCHK (NRTAREFAGERCHK, NRGERENCIAMENTOCHK, NRTAREFACHK, NRFUNCIONARIO, DTHORATAREFAGERCHK, 
                             DSOBSTAREFAGERCHK, IDATIVO, DTINCLUSAO,  CDOPERINCLUSAO)
       VALUES (:NRTAREFAGERCHK, :NRGERENCIAMENTOCHK, :NRTAREFACHK, :NRFUNCIONARIO, :DTHORATAREFAGERCHK, 
                             :DSOBSTAREFAGERCHK, 'S', SYSDATE, :OPERADOR)";
                             
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    public function insertNovaTarefa6($param){
        $sql="INSERT INTO FCM_CRITERIOTARGERCHK (NRCRITERIOTARGERCHK, NMCRITERIOTARGERCHK, NRTAREFAGERCHK, NRCRITERIOTAREFACHK, IDATIVO, 
                                DTINCLUSAO, CDOPERINCLUSAO)
       VALUES (:NRCRITERIOTARGERCHK, :NMCRITERIOTARGERCHK,:NRTAREFAGERCHK, :NRCRITERIOTAREFACHK,  'S', SYSDATE, :OPERADOR)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function deletarTarefaEVistoria($param){
        $this->deletarDependenteTarefaEVistoria($param);
        
        $sql="DELETE FROM FCM_GERENCIAMENTOCHK
               WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
        
        
        $sql="DELETE FROM FCM_CHECKLISTAGEND WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function deletarDependenteTarefaEVistoria($param){
        $sql="DELETE FROM FCM_CRITERIOTARGERCHK
                     WHERE NRTAREFAGERCHK IN (SELECT NRTAREFAGERCHK
                                                FROM FCM_TAREFAGERCHK
                                               WHERE NRGERENCIAMENTOCHK IN (SELECT NRGERENCIAMENTOCHK
                                                                              FROM FCM_GERENCIAMENTOCHK
                                                                             WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND))";
        $std = $this->connection->prepare($sql);
        $std->execute($param);
        
        $sql="DELETE FROM FCM_TAREFAGERCHK 
                    WHERE NRGERENCIAMENTOCHK IN (SELECT NRGERENCIAMENTOCHK
                                                   FROM FCM_GERENCIAMENTOCHK
                                                  WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
        
        
        $sql="DELETE FROM FCM_CRITERIOTARAGEND
               WHERE NRTAREFAAGEND IN (SELECT NRTAREFAAGEND
                                         FROM FCM_TAREFAAGEND 
                                        WHERE NRCHECKLISTAGEND IN (:NRCHECKLISTAGEND))";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
        
        $sql="DELETE FROM FCM_TAREFAAGEND WHERE NRCHECKLISTAGEND IN (:NRCHECKLISTAGEND)";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function updateTarefa($param){
        $sql="UPDATE FCM_CHECKLISTAGEND
                SET NMCHECKLISTAGEND = :NMCHECKLISTAGEND,
                    NRLOCALCLIENTE = :NRLOCALCLIENTE,
                    NRCHECKLIST = :NRCHECKLIST,
                    NRFUNCIONARIO = :NRFUNCIONARIO,
                    DTHORAAGEND = TO_DATE(:DTHORAAGEND,'YYYY/MM/DD HH24:MI'),
                    DTHRFINALAGEND = TO_DATE(:DTHRFINALAGEND, 'YYYY/MM/DD HH24:MI'),
                    CDOPERULTATU = :CDOPERULTATU,
                    DTULTATU = SYSDATE
                WHERE NRCHECKLISTAGEND = :NRCHECKLISTAGEND";
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function updateVistoria($param){
        $sql="UPDATE FCM_GERENCIAMENTOCHK
                SET NMGERENCIAMENTOCHK = :NMGERENCIAMENTOCHK, 
                    NRLOCALCLIENTE = :NRLOCALCLIENTE,
                    NRCHECKLIST = :NRCHECKLIST,
                    NRFUNCIONARIO = :NRFUNCIONARIO,
                    DTHORAAGEND = TO_DATE(:DTHORAAGEND, 'YYYY/MM/DD HH24:MI'),
                    DTHRFINALAGEND = TO_DATE(:DTHRFINALAGEND,'YYYY/MM/DD HH24:MI'),
                    CDOPERULTATU = :OPERADOR,
                    NRCHECKLISTAGEND = :NRCHECKLISTAGEND,
                    DTULTATU = SYSDATE
                WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";
                  
        $std = $this->connection->prepare($sql);
        $std->execute($param);
    }
    
    public function salvarLog($nr,$msg){
        $sql="UPDATE FCM_TAREFARECORRENTE
                SET DSLOGGERACAO = ".$msg."
                WHERE NRGERENCIAMENTOCHK = ".$nr;
                  
        $std = $this->connection->prepare($sql);
        $std->execute();
    }
    
    
}
?>